@@ -103,7 +103,7 @@ class ScriptingView(QtWidgets.QWidget):
         ]
         filename = epyqlib.utils.qt.file_dialog(
             filters,
-            parent=self.ui,
+            parent=self,
         )
 
         if filename is None:
@@ -120,7 +120,7 @@ class ScriptingView(QtWidgets.QWidget):
         filename = epyqlib.utils.qt.file_dialog(
             filters,
             save=True,
-            parent=self.ui,
+            parent=self,
         )
 
         if filename is None:
