@@ -3,11 +3,8 @@
 #TODO: """DocString if there is one"""
 
 import epyqlib.widgets.abstracttxwidget
-import os
-from PyQt5.QtCore import (pyqtSignal, pyqtProperty,
-                          QFile, QFileInfo, QTextStream, Qt, QEvent,
-                          QTimer)
-from PyQt5.QtGui import QMouseEvent
+import epyqlib.widgets.check_ui
+
 
 # See file COPYING in this source tree
 __copyright__ = 'Copyright 2016, EPC Power Corp.'
@@ -16,18 +13,18 @@ __license__ = 'GPLv2+'
 
 class Check(epyqlib.widgets.abstracttxwidget.AbstractTxWidget):
     def __init__(self, parent=None, in_designer=False):
-        ui_file = os.path.join(QFileInfo.absolutePath(QFileInfo(__file__)),
-                               'check.ui')
+        self._frame = None
+        self._signal = None
 
-        epyqlib.widgets.abstracttxwidget.AbstractTxWidget.__init__(self,
-                ui=ui_file, parent=parent, in_designer=in_designer)
+        super().__init__(
+            ui_class=epyqlib.widgets.check_ui.Ui_Form,
+            parent=parent,
+            in_designer=in_designer,
+        )
 
         # TODO: CAMPid 398956661298765098124690765
         self.ui.value.toggled.connect(self.widget_value_changed)
 
-        self._frame = None
-        self._signal = None
-
     def set_value(self, value):
         # TODO: quit hardcoding this and it's better implemented elsewhere
         if self.signal_object is not None:
